| |||||||||||||||||||||||||
| |||||||||||||||||||||||||
| Description | |||||||||||||||||||||||||
Stage1: Lay the ground work for all sorts of Template Haskell hackery in the later stages. Only a handful of class specifications in this file are for later public consumption, and none of those are fleshed out here. This multiple-stage implementation is necessitated by the way Template Haskell is implemented in GHC. | |||||||||||||||||||||||||
| Documentation | |||||||||||||||||||||||||
| mkXT :: Name -> DecQ | |||||||||||||||||||||||||
| mkHT :: Name -> DecQ | |||||||||||||||||||||||||
| class LSN a d a' | a -> d a', d a' -> a | |||||||||||||||||||||||||
| |||||||||||||||||||||||||
| class Trichotomy n s | n -> s | |||||||||||||||||||||||||
| |||||||||||||||||||||||||
| class TEven a b | a -> b | |||||||||||||||||||||||||
| |||||||||||||||||||||||||
| class TSucc n m | n -> m, m -> n | |||||||||||||||||||||||||
| |||||||||||||||||||||||||
| class TAddC' a b c d | a b c -> d | |||||||||||||||||||||||||
| |||||||||||||||||||||||||
| class TNF' a b c | a -> b c | |||||||||||||||||||||||||
| |||||||||||||||||||||||||
| class THex a where | |||||||||||||||||||||||||
| |||||||||||||||||||||||||
| class SHR1 a b c | a b -> c | |||||||||||||||||||||||||
| |||||||||||||||||||||||||
| Produced by Haddock version 0.8 |